USE MASTER
GO

--creating a credential object to talk with azure storage
IF NOT EXISTS
(SELECT * FROM sys.credentials 
WHERE name = 'AzureManagedBackup')
BEGIN
	CREATE Credential AzureManagedBackup
	WITH IDENTITY = '[storage]'
	,SECRET = ''
END

--create a certificate in SQL Server
-- Creates a database master key. 
-- The key is encrypted using the password "<master key password>"
USE master;
GO
CREATE MASTER KEY ENCRYPTION BY PASSWORD = '[pwd]';
GO

-- create a certificate
CREATE CERTIFICATE managedbackupcert
   WITH SUBJECT = 'managedbackupcert';
GO

--enable backup at db level
Use msdb;
GO
EXEC smart_admin.sp_set_db_backup 
                @database_name='AdventureWorks2012' 
                ,@retention_days=30 
                ,@credential_name='AzureManagedBackup'
                ,@encryption_algorithm ='AES_128'
                ,@encryptor_type= 'Certificate'
                ,@encryptor_name='managedbackupcert'
                ,@enable_backup=1;
GO 

-- Review database config settings
USE msdb
GO
SELECT * FROM smart_admin.fn_backup_db_config ('AdventureWorks2012')
SELECT * FROM smart_admin.fn_get_current_xevent_settings()

--Configure ManagedBackup at instance level
Use msdb;
Go
   EXEC smart_admin.sp_set_instance_backup
                 @enable_backup=1
                ,@retention_days=30 
                ,@credential_name='AzureManagedBackup'
                ,@encryption_algorithm ='AES_128'
                ,@encryptor_type= 'Certificate'
                ,@encryptor_name='managedbackupcert';
GO


-- Configure default settings at the instance level
Use msdb
Go
EXEC smart_admin.sp_set_instance_backup
                @retention_days=2, 
                @credential_name='AzureManagedBackup',
                @enable_backup=1
GO 

--review server config settings
SELECT * FROM smart_admin.fn_backup_instance_config ()

-------------------------------------------------------------------------
-- Create 4 new databases
--
DECLARE @str VARCHAR(64)
DECLARE @query VARCHAR(64)
DECLARE @i INT

SET @str = 'CREATE DATABASE TestDB_'
SET @i = 1

WHILE (@i < 6)
BEGIN
	SET @query = @str + CONVERT(VARCHAR(12), @i)
	EXEC (@query)
	SET @i = @i + 1
END

-- View backup configuration
--
SELECT * FROM smart_admin.fn_backup_db_config(NULL)

-------------------------------------------------------------------------
-- Generate workload to trigger log backup for TestDB_2
--

Use TestDB_2
GO

CREATE TABLE t1 (c1 INT, c2 VARCHAR(4000))
GO

DECLARE @i INT
DECLARE @j CHAR

SET @i = 1
SET @j = 'a'

WHILE (@i <= 1000)
BEGIN
	INSERT INTO t1 VALUES (@i, REPLICATE(@j, 4000))
	SET @i = @i + 1
END
GO

-- Check the configuration settings for all databases
Use msdb
GO
SELECT * FROM smart_admin.fn_backup_db_config (NULL)
